==> permission_manager_drf-0.1.0-py3-none-any.whl: permission_manager_drf/utils.py <==
from django.core.exceptions import ImproperlyConfigured
from permission_manager import BasePermissionManager


def get_permission_manager(
    *,
    view,
    instance=None,
    cache: bool = False,
) -> BasePermissionManager:
    """Get a permission manager instance from a view.

    :param view: drf view
    :param instance: model instance
    :param cache: set permission manager cache
    :return: permission_manager instance.
    """
    if view_manager_class := getattr(view, 'get_permission_manager', None):
        manager_class = view_manager_class()
    elif view_manager_class := getattr(view, 'permission_manager', None):
        manager_class = view_manager_class
    elif (queryset := getattr(view, 'queryset', None)) is not None:
        manager_class = get_permission_manager_class_for_model(queryset.model)
    elif model := getattr(view, 'model', None):
        manager_class = get_permission_manager_class_for_model(model)
    else:
        msg = (
            "You must define the 'get_permission_manager' method, "
            "or the 'permission_manager' attribute, or the 'model' "
            'attribute in the view.'
        )
        raise ImproperlyConfigured(msg)

    return manager_class(
        user=view.request.user,
        instance=instance,
        cache=cache,
        **getattr(view, 'get_permission_manager_context', {}),
    )


def get_permission_manager_class_for_model(
    model,
) -> type[BasePermissionManager]:
    """Get a permission manager class from a model.

    :param model: django model
    :return: permission manager class.
    """
    return model.permission_manager

==> permission_manager_drf-0.2.1-py3-none-any.whl: permission_manager_drf/utils.py <==
from django.core.exceptions import ImproperlyConfigured
from django.db.models import Model
from permission_manager import BasePermissionManager
from rest_framework.viewsets import GenericViewSet


def get_permission_manager(
    *,
    view: GenericViewSet,
    instance: Model = None,
    cache: bool = False,
) -> BasePermissionManager:
    """Get a permission manager instance from a view.

    Args:
        view: The DRF view from which to get the permission manager.
        instance: The model instance (optional).
        cache (bool): Whether to enable caching in the permission manager.

    Returns:
        BasePermissionManager: An instance of the permission manager.

    Raises:
        ImproperlyConfigured: If the view does not have a way to determine
            the permission manager.
    """
    if view_manager_class := getattr(view, 'get_permission_manager', None):
        manager_class = view_manager_class()
    elif view_manager_class := getattr(view, 'permission_manager', None):
        manager_class = view_manager_class
    elif (queryset := getattr(view, 'queryset', None)) is not None:
        manager_class = get_permission_manager_class_for_model(queryset.model)
    elif model := getattr(view, 'model', None):
        manager_class = get_permission_manager_class_for_model(model)
    else:
        msg = (
            "You must define the 'get_permission_manager' method, "
            "or the 'permission_manager' attribute, or the 'model' "
            'attribute in the view.'
        )
        raise ImproperlyConfigured(msg)

    return manager_class(
        user=view.request.user,
        instance=instance,
        cache=cache,
        **getattr(view, 'get_permission_manager_context', {}),
    )


def get_permission_manager_class_for_model(
    model: Model,
) -> type[BasePermissionManager]:
    """Get a permission manager class for a given model.

    Args:
        model: The Django model for which to get the permission manager class.

    Returns:
        type[BasePermissionManager]: The permission manager class associated
            with the model.
    """
    return model.permission_manager
